import socket
from unittest import mock

from jupyter_client.localinterfaces import localhost
from jupyter_client.localinterfaces import public_ips

from ipyparallel import util


@mock.patch('warnings.warn')
def test_disambiguate_ip(warn_mock):
    # garbage in, garbage out
    assert util.disambiguate_ip_address('garbage') == 'garbage'
    assert util.disambiguate_ip_address('0.0.0.0', socket.gethostname()) == localhost()
    wontresolve = 'this.wontresolve.dns'
    assert util.disambiguate_ip_address('0.0.0.0', wontresolve) == wontresolve
    assert warn_mock.called_once_with(
        'IPython could not determine IPs for {}: '
        '[Errno -2] Name or service not known'.format(wontresolve),
        RuntimeWarning,
    )
    for ip in public_ips():
        assert util.disambiguate_ip_address('0.0.0.0', ip) == localhost()
